@@ -433,7 +433,24 @@ my $standup_hadoop=sub {
    $os=~s/"$//;
    my $hadoop="]T[{select_hadoop_setup}";
    my $i=$main::aws->{fullauto}->{ImageId}||'';
-   $i='ami-29ebb519' if $os eq 'Ubuntu';
+   if ($os eq 'Ubuntu') {
+      my $region = "wget -qO- http://169.254.169.254/latest/".
+                   "dynamic/instance-identity/document|grep region";
+      $region=`$region`;
+      $region=~s/^.*: ["](.*)["]\s*$/$1/;
+      ($hash,$output,$error)=run_aws_cmd(
+         "aws ec2 describe-images --owners 099720109477 ".
+         "--filters \"Name=root-device-type,Values=ebs\"".
+         " \"Name=virtualization-type,Values=hvm\" ".
+         "\"Name=architecture,Values=x86_64\" --region=$region");
+      my %images=();
+      foreach my $image (@{$hash->{Images}}) {
+         $images{$image->{CreationDate}}=$image
+            if $image->{Name}=~/ubuntu-trusty/;
+      }
+      my $image_hash=$images{(reverse sort keys %{images})[0]};
+      $i=$image_hash->{ImageId};
+   }
    my $s=$main::aws->{fullauto}->
          {NetworkInterfaces}->[0]->{SubnetId}||'';
    my $g=$main::aws->{fullauto}->
@@ -474,8 +491,8 @@ my $standup_hadoop=sub {
       && $error!~/already exists/;
    my $cnt=0;
    my $pemfile=$pem_file;
-   $pemfile=~s/[ ][(]\d+[)]//;
    $pemfile=~s/\.pem\s*$//s;
+   $pemfile=~s/[ ][(]\d+[)]//;
    if (exists $main::aws->{'Hadoop.Apache.org'}) {
       my $g=get_aws_security_id('HadoopSecurityGroup');
       my $c="aws ec2 run-instances --image-id $i --count 1 ".
